@@ -2,7 +2,6 @@ import json
 import os
 from typing import Any, Dict, Optional, cast
 
-import opentracing  # type: ignore
 from chaoslib.types import Configuration, Experiment, Journal, Secrets
 from logzero import logger
 
@@ -20,7 +19,6 @@ def before_experiment_control(
     secrets: Secrets = None,
     **kwargs: Any,
 ) -> None:
-    get_span(org_id, exp_id)
     set_plan_status(org_id, "running", None, configuration, secrets)
 
 
@@ -33,8 +31,6 @@ def after_experiment_control(
     secrets: Secrets = None,
     **kwargs: Any,
 ) -> None:
-    span = get_span(org_id, exp_id)
-
     try:
         result = complete_run(
             org_id, exp_id, context, state, configuration, secrets
@@ -46,9 +42,6 @@ def after_experiment_control(
 
             exec_id = payload["id"]
 
-            if span:
-                span.set_baggage_item("reliably_execution_id", exec_id)
-
             host = secrets.get(
                 "host", os.getenv("RELIABLY_HOST", RELIABLY_HOST)
             )
@@ -59,17 +52,7 @@ def after_experiment_control(
             add_runtime_extra(extension)
             set_plan_status(org_id, "completed", None, configuration, secrets)
     except Exception as ex:
-        logger.debug(
-            f"An error occurred: {ex}, while running the after-experiment "
-            "control, the execution won't be affected.",
-            exc_info=True,
-        )
-        if span:
-            span.set_baggage_item("reliably_error", str(ex))
         set_plan_status(org_id, "error", str(ex), configuration, secrets)
-    finally:
-        if span:
-            span.set_tag("reliably-control", "finished")
 
 
 ###############################################################################
@@ -88,7 +71,6 @@ def complete_run(
             f"/{org_id}/experiments/{exp_id}/executions",
             json={"result": json.dumps(state)},
         )
-        logger.debug(f"Response from {resp.url}: {resp.status_code}")
         if resp.status_code == 201:
             return cast(Dict[str, Any], resp.json())
     return None
@@ -129,25 +111,11 @@ def set_plan_status(
         return None
 
     with get_session(configuration, secrets) as session:
-        resp = session.put(
+        r = session.put(
             f"/{org_id}/plans/{plan_id}/status",
             json={"status": status, "error": message},
         )
-        logger.debug(f"Response from {resp.url}: {resp.status_code}")
-
-
-def get_span(org_id: str, experiment_id: str) -> Optional[opentracing.Span]:
-    tracer = opentracing.global_tracer()
-    scope = tracer.scope_manager.active
-    span = scope.span if scope else None
-    if not span:
-        return None
-
-    span.set_baggage_item("reliably_org_id", org_id)
-    span.set_baggage_item("reliably_experiment_id", experiment_id)
-
-    plan_id = os.getenv("RELIABLY_PLAN_ID")
-    if plan_id:
-        span.set_baggage_item("reliably_plan_id", plan_id)
-
-    return span
+        if r.status_code > 399:
+            logger.debug(
+                f"Failed to set plan status: {r.status_code}: {r.json()}"
+            )
